# Generated by Django 5.1.3 on 2024-12-31 16:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0003_alter_crmuser_options_alter_crmuser_managers'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='crmuser',
            options={'permissions': [('change_access_crmuser', 'Can block/unblock user'), ('reset_password_crmuser', 'Can reset user passwords')], 'verbose_name': 'user', 'verbose_name_plural': 'users'},
        ),
    ]
