# Generated by Django 5.1.4 on 2025-02-06 12:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0002_remove_account_group_type_account_has_bonus_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='account',
            name='is_archived',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='account',
            name='is_trading_enabled',
            field=models.BooleanField(default=True),
        ),
    ]
