# Generated by Django 4.2.21 on 2025-07-18 10:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('transactions', '0011_alter_transaction_options'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='transaction',
            index=models.Index(fields=['customer', 'created_at'], name='transaction_custome_fb8ec8_idx'),
        ),
    ]
