# Generated by Django 4.2.21 on 2025-06-27 15:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ib_commission', '0005_ibonboardingstatus_ib_journey_form_submitted_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='ibonboardingstatus',
            name='creation_source',
            field=models.CharField(blank=True, choices=[('CP', 'Client Portal - Client initiated'), ('CRM', 'CRM - Admin initiated')], help_text='How the IB was created (CP client-initiated or CRM admin-initiated)', max_length=10, null=True),
        ),
    ]
