# Generated by Django 4.2.20 on 2025-04-20 16:54

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0013_usersettings_is_2fa_enabled_and_more'),
        ('customers', '0012_alter_customer_email_alter_customer_first_name_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customerauth',
            name='blocked_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='blocked_customers', to='users.crmuser'),
        ),
        migrations.AlterField(
            model_name='customerauth',
            name='unblocked_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='unblocked_customers', to='users.crmuser'),
        ),
    ]
