# Generated by Django 5.1.4 on 2024-12-25 14:59

import shared_models.users.managers
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0002_alter_crmuser_managers'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='crmuser',
            options={'permissions': [('change_access_crmuser', 'Can block/unblock user')], 'verbose_name': 'user', 'verbose_name_plural': 'users'},
        ),
        migrations.AlterModelManagers(
            name='crmuser',
            managers=[
                ('objects', shared_models.users.managers.UserManager()),
            ],
        ),
    ]
