# Generated by Django 4.2.20 on 2025-05-09 09:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('transactions', '0009_alter_transaction_approved_by_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='transaction',
            name='payment_method',
            field=models.CharField(blank=True, choices=[('WIRE', 'Wire Transfer'), ('CRYPTO', 'Cryptocurrency'), ('CARD', 'Credit/Debit Card'), ('MANUAL', 'Manual Entry'), ('SYSTEM', 'System Generated'), ('UPI', 'UPI Payment'), ('SKRILL', 'Skrill'), ('NETELLER', 'Neteller')], max_length=10, null=True),
        ),
    ]
