# Generated by Django 4.2.19 on 2025-03-20 12:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('customers', '0010_customerauth_blocked_by_customerauth_unblocked_by'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerauth',
            name='reset_token',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='customerauth',
            name='reset_token_expiry',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
