# Generated by Django 4.2.19 on 2025-04-18 16:40

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DashboardTip',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_by', models.CharField(blank=True, max_length=255, null=True)),
                ('updated_by', models.CharField(blank=True, max_length=255, null=True)),
                ('text', models.TextField(help_text='The content of the tip.')),
                ('icon', models.CharField(blank=True, help_text="Optional FontAwesome icon class (e.g., 'faLightbulb').", max_length=50)),
                ('link', models.URLField(blank=True, help_text='Optional URL for the user to click for more info.', null=True)),
                ('is_active', models.BooleanField(default=True, help_text='Whether the tip should be displayed.')),
            ],
            options={
                'verbose_name': 'Dashboard Tip',
                'verbose_name_plural': 'Dashboard Tips',
                'db_table': 'ui_dashboard_tips',
                'ordering': ['-created_at'],
            },
        ),
        migrations.CreateModel(
            name='MotivationalQuote',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_by', models.CharField(blank=True, max_length=255, null=True)),
                ('updated_by', models.CharField(blank=True, max_length=255, null=True)),
                ('text', models.TextField(help_text='The content of the quote.')),
                ('author', models.CharField(blank=True, help_text='The author of the quote.', max_length=100)),
                ('link', models.URLField(blank=True, help_text='Optional URL related to the quote or author.', null=True)),
                ('is_active', models.BooleanField(default=True, help_text='Whether the quote should be displayed.')),
            ],
            options={
                'verbose_name': 'Motivational Quote',
                'verbose_name_plural': 'Motivational Quotes',
                'db_table': 'ui_motivational_quotes',
                'ordering': ['-created_at'],
            },
        ),
    ]
