# Generated by Django 5.1.4 on 2025-01-02 12:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0004_alter_crmuser_options'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='crmuser',
            name='is_2fa_enabled',
        ),
        migrations.RemoveField(
            model_name='crmuser',
            name='two_factor_secret',
        ),
        migrations.AddField(
            model_name='usersettings',
            name='backup_codes',
            field=models.JSONField(blank=True, default=list, null=True),
        ),
        migrations.AddField(
            model_name='usersettings',
            name='preferred_2fa_method',
            field=models.CharField(blank=True, choices=[('totp', 'Authenticator App'), ('security_key', 'Security Key'), ('sms', 'SMS')], default='totp', max_length=20, null=True),
        ),
        migrations.AddField(
            model_name='usersettings',
            name='security_keys',
            field=models.JSONField(blank=True, default=list, null=True),
        ),
    ]
