# Generated by Django 4.2.19 on 2025-02-09 17:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('transactions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='transaction',
            name='mt5_ticket',
            field=models.CharField(blank=True, help_text='MT5 ticket number for the transaction', max_length=50, null=True),
        ),
    ]
