# Generated by Django 5.1.4 on 2025-01-02 13:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0007_alter_usersettings_options_alter_usersettings_table'),
    ]

    operations = [
        migrations.AddField(
            model_name='usersettings',
            name='temp_webauthn_challenge',
            field=models.CharField(blank=True, max_length=512, null=True),
        ),
    ]
