# Generated by Django 4.2.20 on 2025-06-10 10:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('company_ba', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='companybankaccount',
            options={'ordering': ['-created_at'], 'verbose_name': 'Company Bank Account', 'verbose_name_plural': 'Company Bank Accounts'},
        ),
    ]
