# Generated by Django 4.2.20 on 2025-04-19 11:09

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CustomerUPI',
            fields=[
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_by', models.CharField(blank=True, max_length=255, null=True)),
                ('updated_by', models.CharField(blank=True, max_length=255, null=True)),
                ('id', models.AutoField(editable=False, primary_key=True, serialize=False)),
                ('customer_id', models.IntegerField(db_index=True)),
                ('upi_id', models.CharField(max_length=255)),
                ('display_name', models.CharField(max_length=255)),
                ('is_primary', models.BooleanField(default=False)),
                ('is_active', models.BooleanField(default=True)),
                ('comment', models.TextField(blank=True, help_text='Additional notes about this UPI ID', null=True)),
            ],
            options={
                'verbose_name': 'Customer UPI',
                'verbose_name_plural': 'Customer UPIs',
                'db_table': 'shared_customer_upi',
                'ordering': ['-created_at'],
                'permissions': [('view_customer_upi', 'Can view customer UPI'), ('delete_customer_upi', 'Can delete customer UPI'), ('change_customer_upi', 'Can change customer UPI'), ('add_customer_upi', 'Can add customer UPI')],
                'indexes': [models.Index(fields=['customer_id'], name='shared_cust_custome_f9f7fd_idx'), models.Index(fields=['upi_id'], name='shared_cust_upi_id_2d9673_idx')],
            },
        ),
    ]
