# Generated by Django 4.2.20 on 2025-04-22 10:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ib_commission', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='commissiondistribution',
            name='processed_time',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
