# Generated by Django 4.2.19 on 2025-02-25 14:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('customers', '0004_customerauth_two_factor_backup_codes_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerauth',
            name='temp_webauthn_challenge',
            field=models.CharField(blank=True, max_length=512, null=True),
        ),
    ]
