# Generated by Django 4.2.20 on 2025-04-20 16:54

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0013_usersettings_is_2fa_enabled_and_more'),
        ('transactions', '0008_alter_transaction_payment_method'),
    ]

    operations = [
        migrations.AlterField(
            model_name='transaction',
            name='approved_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='approved_transactions', to='users.crmuser'),
        ),
        migrations.AlterField(
            model_name='transaction',
            name='assigned_user',
            field=models.ForeignKey(blank=True, help_text="The CRM user assigned to this transaction's customer at the time of creation.", null=True, on_delete=django.db.models.deletion.PROTECT, related_name='assigned_transactions', to='users.crmuser'),
        ),
    ]
