# Generated by Django 4.2.21 on 2025-07-23 07:41

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ib_commission', '0009_ibcommissionrule_min_volume'),
    ]

    operations = [
        migrations.AlterField(
            model_name='commissiondistribution',
            name='rule',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='distributions', to='ib_commission.ibcommissionrule'),
        ),
        migrations.AlterField(
            model_name='commissiontracking',
            name='rule',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='commissions', to='ib_commission.ibcommissionrule'),
        ),
        migrations.AlterField(
            model_name='ibcommissionrule',
            name='agreement',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='commission_rules', to='ib_commission.ibagreement'),
        ),
    ]
