# Generated by Django 4.2.19 on 2025-02-17 11:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('transactions', '0002_transaction_mt5_ticket'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='transaction',
            options={'ordering': ['-created_at'], 'permissions': [('view_own_transaction', 'Can view own customer transactions'), ('view_team_transaction', "Can view team's customer transactions"), ('view_all_transaction', 'Can view all customer transactions'), ('approve_transaction', 'Can approve transactions'), ('reject_transaction', 'Can reject transactions')]},
        ),
    ]
