# Generated by Django 4.2.20 on 2025-06-10 10:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('shared_customer_crypto_wallet', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='customercryptowallet',
            options={'ordering': ['-created_at'], 'permissions': [('verify_customercryptowallet', 'Can verify customer crypto wallet'), ('approve_customercryptowallet', 'Can approve customer crypto wallet'), ('set_primary_customercryptowallet', 'Can set primary crypto wallet')], 'verbose_name': 'Customer Crypto Wallet', 'verbose_name_plural': 'Customer Crypto Wallets'},
        ),
    ]
