# Generated by Django 4.2.21 on 2025-07-18 11:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ib_commission', '0008_ibcommissionrule_lot_size'),
    ]

    operations = [
        migrations.AddField(
            model_name='ibcommissionrule',
            name='min_volume',
            field=models.DecimalField(decimal_places=2, default=0.0, help_text='Minimum volume (in lots) required to qualify for this rule', max_digits=10),
        ),
    ]
