# Generated by Django 4.2.20 on 2025-06-10 10:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('system_settings', '0015_alter_paymentgatewayconfig_payment_method_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='emailconfiguration',
            options={'verbose_name': 'Email Configuration', 'verbose_name_plural': 'Email Configurations'},
        ),
        migrations.AlterModelOptions(
            name='emailcontent',
            options={'verbose_name': 'Email Content', 'verbose_name_plural': 'Email Contents'},
        ),
        migrations.AlterModelOptions(
            name='emailtemplate',
            options={'verbose_name': 'Email Template', 'verbose_name_plural': 'Email Templates'},
        ),
        migrations.AlterModelOptions(
            name='groupconfiguration',
            options={'verbose_name': 'Group Configuration', 'verbose_name_plural': 'Group Configurations'},
        ),
        migrations.AlterModelOptions(
            name='ibcustomgroupconfiguration',
            options={'verbose_name': 'IB Custom Group Configuration', 'verbose_name_plural': 'IB Custom Group Configurations'},
        ),
        migrations.AlterModelOptions(
            name='systememail',
            options={'verbose_name': 'System Email', 'verbose_name_plural': 'System Emails'},
        ),
    ]
