# Generated by Django 4.2.21 on 2025-06-27 15:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ib_commission', '0004_ibonboardingstatus'),
    ]

    operations = [
        migrations.AddField(
            model_name='ibonboardingstatus',
            name='ib_journey_form_submitted',
            field=models.BooleanField(default=False, help_text='IB has submitted the IB journey application form'),
        ),
        migrations.AddField(
            model_name='ibonboardingstatus',
            name='ib_request_id',
            field=models.IntegerField(blank=True, db_index=True, help_text='ID of the IB journey form submission (IBRequest from backend-py project)', null=True),
        ),
    ]
