# Generated by Django 4.2.20 on 2025-06-10 10:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('customers', '0013_alter_customerauth_blocked_by_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='customer',
            options={'permissions': [('assign_customer', 'Can assign customers to CRM users'), ('manage_customer_status', 'Can manage customer status (lead/client/IB)'), ('block_customer', 'Can block/unblock customer'), ('manage_customer_trading_controls', 'Can manage customer trading controls'), ('manage_customer_transaction_controls', 'Can manage customer transaction controls'), ('manage_customer_sensitive_data', 'Can manage sensitive customer data'), ('verify_customer_kyc', 'Can verify customer KYC documents'), ('manage_customer_ib_status', 'Can manage customer IB status'), ('export_customer_data', 'Can export customer data'), ('view_customer_sensitive_fields', 'Can view customer sensitive fields'), ('approve_customer_changes', 'Can approve pending customer changes'), ('set_customer_call_status', 'Can set customer call status')], 'verbose_name_plural': 'customers'},
        ),
    ]
