# Generated by Django 4.2.19 on 2025-04-11 12:06

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('system_settings', '0012_alter_emailcontent_content_sections'),
    ]

    operations = [
        migrations.CreateModel(
            name='KycRequirementRule',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_by', models.CharField(blank=True, max_length=255, null=True)),
                ('updated_by', models.CharField(blank=True, max_length=255, null=True)),
                ('transaction_type', models.CharField(blank=True, help_text='Apply rule only to this transaction type (e.g., DEPOSIT, WITHDRAWAL) (optional)', max_length=50, null=True)),
                ('requires_level_one', models.BooleanField(default=False, help_text='Does this rule require at least KYC Level One?')),
                ('requires_level_two', models.BooleanField(default=False, help_text='Does this rule require at least KYC Level Two?')),
                ('requires_level_three', models.BooleanField(default=False, help_text='Does this rule require at least KYC Level Three?')),
                ('payment_gateway', models.ForeignKey(blank=True, help_text='Apply rule only to this payment gateway (optional)', null=True, on_delete=django.db.models.deletion.CASCADE, to='system_settings.paymentgatewayconfig')),
                ('payment_method', models.ForeignKey(blank=True, help_text='Apply rule only to this payment method (optional)', null=True, on_delete=django.db.models.deletion.CASCADE, to='system_settings.paymentmethodconfig')),
            ],
            options={
                'verbose_name': 'KYC Requirement Rule',
                'verbose_name_plural': 'KYC Requirement Rules',
                'db_table': 'system_settings_kycrequirementrule',
                'ordering': ['payment_method', 'payment_gateway', 'transaction_type'],
            },
        ),
    ]
