# Generated by Django 4.2.19 on 2025-02-21 18:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('customers', '0002_alter_customer_email_alter_customer_first_name_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerauth',
            name='two_factor_backup_codes',
            field=models.JSONField(default=list),
        ),
        migrations.AddField(
            model_name='customerauth',
            name='two_factor_enabled',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='customerauth',
            name='two_factor_secret',
            field=models.CharField(blank=True, max_length=32),
        ),
        migrations.AddField(
            model_name='customerauth',
            name='webauthn_credentials',
            field=models.JSONField(default=list),
        ),
    ]
