# Generated by Django 4.2.21 on 2025-06-26 13:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ib_commission', '0002_alter_commissiondistribution_processed_time'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='clientibmapping',
            index=models.Index(fields=['mt5_login', 'customer'], name='idx_client_mapping_lookup'),
        ),
        migrations.AddIndex(
            model_name='clientibmapping',
            index=models.Index(fields=['customer', 'direct_ib_customer'], name='idx_client_mapping_ib'),
        ),
        migrations.AddIndex(
            model_name='ibagreementmember',
            index=models.Index(fields=['customer', 'is_active'], name='idx_agreement_member_lookup'),
        ),
        migrations.AddIndex(
            model_name='ibagreementmember',
            index=models.Index(fields=['agreement', 'is_active'], name='idx_agreement_member_reverse'),
        ),
        migrations.AddIndex(
            model_name='ibcommissionrule',
            index=models.Index(fields=['agreement', 'commission_type', 'symbol'], name='idx_rule_lookup'),
        ),
        migrations.AddIndex(
            model_name='ibcommissionrule',
            index=models.Index(fields=['agreement', 'commission_type', 'priority'], name='idx_rule_priority'),
        ),
        migrations.AddIndex(
            model_name='ibcommissionrule',
            index=models.Index(fields=['agreement', 'account_type'], name='idx_rule_account_type'),
        ),
        migrations.AddIndex(
            model_name='ibhierarchy',
            index=models.Index(fields=['customer', 'is_active'], name='idx_hierarchy_lookup'),
        ),
        migrations.AddIndex(
            model_name='ibhierarchy',
            index=models.Index(fields=['path'], name='idx_hierarchy_path'),
        ),
    ]
