# Generated by Django 4.2.21 on 2025-06-21 14:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system_settings', '0017_brokerconfiguration'),
    ]

    operations = [
        migrations.AddField(
            model_name='accounttype',
            name='demo_auto_deposit_amount',
            field=models.DecimalField(decimal_places=2, default=10000.0, help_text='Auto deposit amount for demo accounts in USD', max_digits=10),
        ),
    ]
