# Generated by Django 4.2.20 on 2025-04-19 11:09

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CustomerCryptoWallet',
            fields=[
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_by', models.CharField(blank=True, max_length=255, null=True)),
                ('updated_by', models.CharField(blank=True, max_length=255, null=True)),
                ('id', models.AutoField(editable=False, primary_key=True, serialize=False)),
                ('customer_id', models.IntegerField(db_index=True)),
                ('address', models.CharField(max_length=255)),
                ('network', models.CharField(max_length=255)),
                ('token', models.CharField(max_length=255)),
                ('is_primary', models.BooleanField(default=False)),
                ('is_active', models.BooleanField(default=True)),
                ('comment', models.TextField(blank=True, help_text='Additional notes about this crypto wallet', null=True)),
            ],
            options={
                'verbose_name': 'Customer Crypto Wallet',
                'verbose_name_plural': 'Customer Crypto Wallets',
                'db_table': 'shared_customer_crypto_wallets',
                'ordering': ['-created_at'],
                'permissions': [('view_customer_crypto_wallet', 'Can view customer crypto wallet'), ('delete_customer_crypto_wallet', 'Can delete customer crypto wallet'), ('change_customer_crypto_wallet', 'Can change customer crypto wallet'), ('add_customer_crypto_wallet', 'Can add customer crypto wallet')],
                'indexes': [models.Index(fields=['customer_id'], name='shared_cust_custome_3afa4d_idx'), models.Index(fields=['address', 'network'], name='shared_cust_address_0d3c47_idx'), models.Index(fields=['token'], name='shared_cust_token_2e727a_idx')],
            },
        ),
    ]
