# Generated by Django 4.2.20 on 2025-04-24 16:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('referrals', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='referralreward',
            name='payment_gateway',
            field=models.CharField(blank=True, help_text='Specific payment gateway to simulate for deposit rewards (optional).', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='referralreward',
            name='payment_method',
            field=models.CharField(blank=True, help_text='Specific payment method to simulate for deposit rewards (optional).', max_length=50, null=True),
        ),
    ]
