# Generated by Django 5.1.4 on 2024-12-24 10:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='crmuser',
            managers=[
            ],
        ),
    ]
