# Generated by Django 4.2.20 on 2025-04-19 08:35

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CompanyCryptoWallet',
            fields=[
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_by', models.CharField(blank=True, max_length=255, null=True)),
                ('updated_by', models.CharField(blank=True, max_length=255, null=True)),
                ('id', models.AutoField(editable=False, primary_key=True, serialize=False)),
                ('address', models.CharField(max_length=255)),
                ('network', models.CharField(max_length=255)),
                ('token', models.CharField(max_length=255)),
                ('show_only_in_countries', models.CharField(blank=True, help_text='Comma-separated list of country codes where this wallet should be shown', max_length=255)),
                ('excluded_countries', models.CharField(blank=True, help_text='Comma-separated list of country codes where this wallet should NOT be shown', max_length=255)),
            ],
            options={
                'verbose_name': 'Company Crypto Wallet',
                'verbose_name_plural': 'Company Crypto Wallets',
                'db_table': 'company_crypto_wallets',
                'ordering': ['-created_at'],
                'permissions': [('view_company_crypto_wallet', 'Can view company crypto wallet'), ('delete_company_crypto_wallet', 'Can delete company crypto wallet'), ('change_company_crypto_wallet', 'Can change company crypto wallet'), ('add_company_crypto_wallet', 'Can add company crypto wallet')],
                'indexes': [models.Index(fields=['address', 'network'], name='company_cry_address_f19bfa_idx'), models.Index(fields=['token'], name='company_cry_token_395570_idx')],
            },
        ),
    ]
