# Generated by Django 4.2.19 on 2025-02-09 17:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0004_alter_account_created_at_alter_account_created_by_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='account',
            name='currency',
            field=models.CharField(default='USD', max_length=3),
        ),
    ]
