# Generated by Django 4.2.19 on 2025-02-26 14:04

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('customers', '0006_customerauth_webauthn_challenge'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerauth',
            name='blocked',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='customerauth',
            name='blocked_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='customerauth',
            name='blocked_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='blocked_customers', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='customerauth',
            name='blocked_reason',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='customerauth',
            name='unblocked_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='customerauth',
            name='unblocked_by',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='unblocked_customers', to=settings.AUTH_USER_MODEL),
        ),
    ]
