# Generated by Django 4.2.19 on 2025-02-08 19:05

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system_settings', '0009_alter_accountsequence_created_at_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentgatewayconfig',
            name='gateway',
            field=models.CharField(help_text='Unique identifier for the gateway. Must be uppercase with underscores (e.g. NEG_BALANCE_COVERAGE)', max_length=50, unique=True, validators=[django.core.validators.RegexValidator(message='Gateway name must be uppercase and contain only letters, numbers, and underscores', regex='^[A-Z][A-Z0-9_]*$')]),
        ),
        migrations.AlterField(
            model_name='paymentmethodconfig',
            name='allowed_gateways',
            field=models.ManyToManyField(blank=True, related_name='payment_methods', to='system_settings.paymentgatewayconfig'),
        ),
    ]
