# Generated by Django 4.2.20 on 2025-04-10 10:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system_settings', '0011_tradingplatformserverlog'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailcontent',
            name='content_sections',
            field=models.JSONField(default=dict, help_text="Dict mapping template placeholders to content structures. Each structure has 'default' content and optional 'condition_sets'. Content can include {{ variables }}."),
        ),
    ]
