# Generated by Django 5.1.4 on 2025-01-02 12:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0005_remove_crmuser_is_2fa_enabled_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='usersettings',
            old_name='preferred_2fa_method',
            new_name='default_2fa_method',
        ),
        migrations.AddField(
            model_name='usersettings',
            name='active_2fa_methods',
            field=models.JSONField(blank=True, default=dict, null=True),
        ),
        migrations.AlterModelTable(
            name='usersettings',
            table=None,
        ),
    ]
