# Generated by Django 4.2.20 on 2025-06-10 10:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('transactions', '0010_alter_transaction_payment_method'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='transaction',
            options={'ordering': ['-created_at'], 'permissions': [('approve_transaction', 'Can approve transactions'), ('reject_transaction', 'Can reject transactions')]},
        ),
    ]
