# Generated by Django 4.2.20 on 2025-06-10 10:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0014_alter_crmuser_groups_alter_crmuser_user_permissions_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='crmuser',
            options={'permissions': [('change_access_crmuser', 'Can block/unblock user'), ('reset_password_crmuser', 'Can reset user passwords'), ('can_assign_users', 'Can assign users to customers'), ('can_be_assigned', 'Can be assigned to customers'), ('view_own_dashboard', 'Can view own dashboard metrics'), ('view_all_users_activity', 'Can view all users activity analytics'), ('view_team_analytics', 'Can view team analytics'), ('view_customer_analytics', 'Can view customer analytics'), ('view_transaction_analytics', 'Can view transaction analytics'), ('view_ib_analytics', 'Can view IB analytics'), ('view_support_analytics', 'Can view support analytics'), ('view_request_analytics', 'Can view request analytics')], 'verbose_name': 'user', 'verbose_name_plural': 'users'},
        ),
    ]
