# Generated by Django 4.2.20 on 2025-04-26 09:16

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CompanyBankAccount',
            fields=[
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_by', models.CharField(blank=True, max_length=255, null=True)),
                ('updated_by', models.CharField(blank=True, max_length=255, null=True)),
                ('id', models.AutoField(editable=False, primary_key=True, serialize=False)),
                ('bank_name', models.CharField(max_length=255)),
                ('country', models.CharField(max_length=255)),
                ('currency', models.CharField(max_length=255)),
                ('account_number', models.CharField(max_length=255)),
                ('iban', models.CharField(max_length=255)),
                ('swift', models.CharField(max_length=255)),
                ('ifsc', models.CharField(max_length=255)),
                ('address', models.TextField(blank=True, default='')),
                ('account_holder_name', models.CharField(default='', max_length=255)),
            ],
            options={
                'verbose_name': 'Company Bank Account',
                'verbose_name_plural': 'Company Bank Accounts',
                'db_table': 'company_bank_accounts',
                'ordering': ['-created_at'],
                'permissions': [('view_company_bank_account', 'Can view company bank account'), ('delete_company_bank_account', 'Can delete company bank account'), ('change_company_bank_account', 'Can change company bank account'), ('add_company_bank_account', 'Can add company bank account')],
                'indexes': [models.Index(fields=['bank_name', 'country'], name='company_ban_bank_na_b2e9d5_idx'), models.Index(fields=['account_number'], name='company_ban_account_13481d_idx')],
            },
        ),
    ]
