# Generated by Django 4.2.19 on 2025-04-18 16:40

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('transactions', '0006_transaction_approved_at'),
    ]

    operations = [
        migrations.AddField(
            model_name='transaction',
            name='assigned_user',
            field=models.ForeignKey(blank=True, help_text="The CRM user assigned to this transaction's customer at the time of creation.", null=True, on_delete=django.db.models.deletion.PROTECT, related_name='assigned_transactions', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddIndex(
            model_name='transaction',
            index=models.Index(fields=['assigned_user'], name='transaction_assigne_935da3_idx'),
        ),
    ]
