# Generated by Django 4.2.20 on 2025-04-15 16:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('customers', '0011_customerauth_reset_token_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='email',
            field=models.EmailField(max_length=254, unique=True, verbose_name='email address'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='first_name',
            field=models.CharField(blank=True, max_length=150),
        ),
        migrations.AlterField(
            model_name='customer',
            name='last_name',
            field=models.CharField(blank=True, max_length=150),
        ),
        migrations.AlterField(
            model_name='customer',
            name='mobile',
            field=models.CharField(blank=True, max_length=20),
        ),
        migrations.AlterField(
            model_name='customer',
            name='phone',
            field=models.CharField(blank=True, max_length=20),
        ),
        migrations.AlterField(
            model_name='customerdetail',
            name='address',
            field=models.CharField(blank=True, max_length=500),
        ),
        migrations.AlterField(
            model_name='customerdetail',
            name='address2',
            field=models.CharField(blank=True, max_length=500),
        ),
        migrations.AlterField(
            model_name='customerdetail',
            name='city',
            field=models.CharField(blank=True, max_length=100),
        ),
        migrations.AlterField(
            model_name='customerdetail',
            name='title',
            field=models.CharField(blank=True, max_length=10),
        ),
        migrations.AlterField(
            model_name='customerdetail',
            name='zip_code',
            field=models.CharField(blank=True, max_length=20),
        ),
    ]
