# Generated by Django 4.2.19 on 2025-03-18 10:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0012_alter_crmuser_managers_usersettings_is_2fa_enabled_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='usersettings',
            name='is_2fa_enabled',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='usersettings',
            name='two_factor_secret',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
