# Generated by Django 4.2.20 on 2025-04-10 10:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('transactions', '0004_alter_transaction_created_by'),
    ]

    operations = [
        migrations.AlterField(
            model_name='transaction',
            name='status',
            field=models.CharField(choices=[('PENDING', 'Pending'), ('APPROVED', 'Approved'), ('REJECTED', 'Rejected'), ('CANCELLED', 'Cancelled'), ('FAILED', 'Failed'), ('PROCESSED', 'Processed')], default='PENDING', max_length=10),
        ),
    ]
