# Generated by Django 4.2.19 on 2025-02-25 19:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('customers', '0005_customerauth_temp_webauthn_challenge'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerauth',
            name='webauthn_challenge',
            field=models.CharField(blank=True, max_length=512, null=True),
        ),
    ]
