# Generated by Django 5.1.4 on 2025-01-23 11:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0009_alter_userprofile_profile_picture'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='crmuser',
            options={'permissions': [('change_access_crmuser', 'Can block/unblock user'), ('reset_password_crmuser', 'Can reset user passwords'), ('can_assign_users', 'Can assign users to customers')], 'verbose_name': 'user', 'verbose_name_plural': 'users'},
        ),
    ]
