# Generated by Django 5.1.4 on 2025-01-09 15:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0008_usersettings_temp_webauthn_challenge'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userprofile',
            name='profile_picture',
            field=models.CharField(blank=True, max_length=500, null=True),
        ),
    ]
