# Generated by Django 5.1.4 on 2025-01-17 13:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system_settings', '0003_tradingplatformserver'),
    ]

    operations = [
        migrations.AddField(
            model_name='tradingplatformserver',
            name='connection_timeout',
            field=models.IntegerField(default=30),
        ),
        migrations.AddField(
            model_name='tradingplatformserver',
            name='health_check_interval',
            field=models.IntegerField(default=30),
        ),
        migrations.AddField(
            model_name='tradingplatformserver',
            name='is_connected',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='tradingplatformserver',
            name='max_retries',
            field=models.IntegerField(default=3),
        ),
        migrations.AddField(
            model_name='tradingplatformserver',
            name='retry_max_wait',
            field=models.IntegerField(default=30),
        ),
        migrations.AddField(
            model_name='tradingplatformserver',
            name='retry_min_wait',
            field=models.IntegerField(default=1),
        ),
    ]
