# Generated by Django 4.2.21 on 2025-06-26 13:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('trading', '0004_alter_deal_id'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='deal',
            index=models.Index(fields=['position_id', 'login', 'entry'], name='idx_deal_position_lookup'),
        ),
        migrations.AddIndex(
            model_name='deal',
            index=models.Index(fields=['login', 'time'], name='idx_deal_login_time'),
        ),
    ]
