# Generated by Django 4.2.19 on 2025-02-19 07:43

from django.db import migrations
import encrypted_model_fields.fields


class Migration(migrations.Migration):

    dependencies = [
        ('customers', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='email',
            field=encrypted_model_fields.fields.EncryptedEmailField(unique=True, verbose_name='email address'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='first_name',
            field=encrypted_model_fields.fields.EncryptedCharField(blank=True),
        ),
        migrations.AlterField(
            model_name='customer',
            name='last_name',
            field=encrypted_model_fields.fields.EncryptedCharField(blank=True),
        ),
        migrations.AlterField(
            model_name='customer',
            name='mobile',
            field=encrypted_model_fields.fields.EncryptedCharField(blank=True),
        ),
        migrations.AlterField(
            model_name='customer',
            name='phone',
            field=encrypted_model_fields.fields.EncryptedCharField(blank=True),
        ),
        migrations.AlterField(
            model_name='customerdetail',
            name='address',
            field=encrypted_model_fields.fields.EncryptedCharField(blank=True),
        ),
        migrations.AlterField(
            model_name='customerdetail',
            name='address2',
            field=encrypted_model_fields.fields.EncryptedCharField(blank=True),
        ),
        migrations.AlterField(
            model_name='customerdetail',
            name='city',
            field=encrypted_model_fields.fields.EncryptedCharField(blank=True),
        ),
        migrations.AlterField(
            model_name='customerdetail',
            name='title',
            field=encrypted_model_fields.fields.EncryptedCharField(blank=True),
        ),
        migrations.AlterField(
            model_name='customerdetail',
            name='zip_code',
            field=encrypted_model_fields.fields.EncryptedCharField(blank=True),
        ),
    ]
