# Generated by Django 4.2.19 on 2025-02-17 11:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0005_account_currency'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='account',
            options={'permissions': [('view_own_account', 'Can view own customer accounts'), ('view_team_account', "Can view team's customer accounts"), ('view_all_account', 'Can view all customer accounts'), ('change_account_group', 'Can change account group')], 'verbose_name': 'Account', 'verbose_name_plural': 'Accounts'},
        ),
    ]
