# Generated by Django 4.2.20 on 2025-06-10 10:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0006_alter_account_options'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='account',
            options={'permissions': [('enable_account_trading', 'Can enable/disable account trading'), ('archive_account', 'Can archive account'), ('reset_account_password', 'Can reset account password'), ('change_account_leverage', 'Can change account leverage'), ('change_account_group', 'Can change account group'), ('manage_account_bonus', 'Can manage account bonus settings'), ('manage_account_markup', 'Can manage account markup settings'), ('change_account_swap_status', 'Can change swap-free status'), ('view_account_trading_activity', 'Can view account trading activity (positions, orders, deals)'), ('view_account_analytics', 'Can view account analytics and charts')], 'verbose_name': 'Account', 'verbose_name_plural': 'Accounts'},
        ),
    ]
