# Generated by Django 5.1.4 on 2025-02-04 11:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accounts', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='account',
            name='group_type',
        ),
        migrations.AddField(
            model_name='account',
            name='has_bonus',
            field=models.BooleanField(default=False, help_text='Whether this account has bonus applied'),
        ),
        migrations.AddField(
            model_name='account',
            name='has_markup',
            field=models.BooleanField(default=False, help_text='Whether this account has markup applied'),
        ),
    ]
