# Generated by Django 4.2.21 on 2025-07-18 06:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ib_commission', '0007_ibquestionnaire'),
    ]

    operations = [
        migrations.AddField(
            model_name='ibcommissionrule',
            name='lot_size',
            field=models.DecimalField(decimal_places=2, default=1.0, help_text='Number of lots this value applies to (for LOT_BASED calculation)', max_digits=10),
        ),
    ]
