# Generated by Django 5.1.4 on 2025-01-16 11:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('system_settings', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='systemsetting',
            old_name='is_enabled',
            new_name='is_active',
        ),
    ]
