# Generated by Django 5.1.4 on 2025-02-03 14:22

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('system_settings', '0005_accountsequence_accounttype'),
    ]

    operations = [
        migrations.AlterField(
            model_name='accounttype',
            name='sequence',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='account_types', to='system_settings.accountsequence'),
        ),
    ]
