# Generated by Django 4.2.20 on 2025-04-19 08:35

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CompanyUpiId',
            fields=[
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('created_by', models.CharField(blank=True, max_length=255, null=True)),
                ('updated_by', models.CharField(blank=True, max_length=255, null=True)),
                ('id', models.AutoField(editable=False, primary_key=True, serialize=False)),
                ('upi_id', models.CharField(max_length=255)),
                ('name', models.CharField(max_length=255)),
                ('bank', models.CharField(max_length=255)),
                ('owner_name', models.CharField(max_length=255)),
                ('show_only_in_countries', models.CharField(blank=True, help_text='Comma-separated list of country codes where this UPI ID should be shown', max_length=255)),
                ('excluded_countries', models.CharField(blank=True, help_text='Comma-separated list of country codes where this UPI ID should NOT be shown', max_length=255)),
            ],
            options={
                'verbose_name': 'Company UPI ID',
                'verbose_name_plural': 'Company UPI IDs',
                'db_table': 'company_upi_ids',
                'ordering': ['-created_at'],
                'permissions': [('view_company_upi_id', 'Can view company UPI ID'), ('delete_company_upi_id', 'Can delete company UPI ID'), ('change_company_upi_id', 'Can change company UPI ID'), ('add_company_upi_id', 'Can add company UPI ID')],
                'indexes': [models.Index(fields=['upi_id', 'bank'], name='company_upi_upi_id_f60a1a_idx'), models.Index(fields=['owner_name'], name='company_upi_owner_n_e971a7_idx')],
            },
        ),
    ]
