# Generated by Django 5.1.4 on 2025-01-02 12:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0006_rename_preferred_2fa_method_usersettings_default_2fa_method_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='usersettings',
            options={'verbose_name': 'User Settings', 'verbose_name_plural': 'User Settings'},
        ),
        migrations.AlterModelTable(
            name='usersettings',
            table='crm_user_settings',
        ),
    ]
