# Generated by Django 4.2.20 on 2025-04-20 16:54

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('users', '0013_usersettings_is_2fa_enabled_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='crmuser',
            name='groups',
            field=models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='crmuser_groups', related_query_name='crmuser', to='auth.group', verbose_name='groups'),
        ),
        migrations.AlterField(
            model_name='crmuser',
            name='user_permissions',
            field=models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='crmuser_permissions', related_query_name='crmuser', to='auth.permission', verbose_name='user permissions'),
        ),
        migrations.AlterField(
            model_name='userprofile',
            name='reporting_manager',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='team_members', to='users.crmuser'),
        ),
        migrations.AlterField(
            model_name='userprofile',
            name='user',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='profile', to='users.crmuser'),
        ),
        migrations.AlterField(
            model_name='usersettings',
            name='user',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='settings', to='users.crmuser'),
        ),
    ]
