# Generated by Django 4.2.20 on 2025-04-15 15:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('transactions', '0005_alter_transaction_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='transaction',
            name='approved_at',
            field=models.DateTimeField(blank=True, help_text='Timestamp when the transaction was approved', null=True),
        ),
    ]
