# Generated by Django 4.2.21 on 2025-07-23 09:08

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ib_commission', '0010_alter_commissiondistribution_rule_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='clientibmapping',
            name='agreement',
            field=models.ForeignKey(blank=True, help_text='Default agreement for this client-IB relationship', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='client_mappings', to='ib_commission.ibagreement'),
        ),
        migrations.AlterField(
            model_name='ibagreementmember',
            name='agreement',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='members', to='ib_commission.ibagreement'),
        ),
    ]
