# Generated by Django 4.2.20 on 2025-06-10 10:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('shared_email_campaign', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='emailcampaign',
            options={'ordering': ['-created_at'], 'permissions': [('manage_emailcampaign_schedule', 'Can schedule and cancel email campaigns'), ('send_emailcampaign_test', 'Can send test emails'), ('view_emailcampaign_statistics', 'Can view campaign statistics and reports'), ('access_emailcampaign_recipient_count', 'Can access recipient count')], 'verbose_name': 'Email Campaign', 'verbose_name_plural': 'Email Campaigns'},
        ),
        migrations.AlterModelOptions(
            name='emailcampaigncontent',
            options={'ordering': ['-created_at'], 'permissions': [], 'verbose_name': 'Email Campaign Content', 'verbose_name_plural': 'Email Campaign Contents'},
        ),
    ]
