# Generated by Django 4.2.19 on 2025-03-16 09:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('customers', '0008_customer_email_hash'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='customerauth',
            name='blocked_by',
        ),
        migrations.RemoveField(
            model_name='customerauth',
            name='unblocked_by',
        ),
    ]
